@@ -1,5 +1,7 @@
 
 from repoze.pgtextindex.queryparser import QueryParser
+from repoze.pgtextindex.queryparser import remove_special_chars
+
 
 def convert_query(query):
     """Convert a Zope text index query to PostgreSQL tsearch format"""
@@ -10,6 +12,7 @@ def convert_query(query):
     tree = QueryParser().parseQuery(text)
     return ParseTreeEncoder().encode(tree)
 
+
 class ParseTreeEncoder:
 
     def encode(self, node):
@@ -31,8 +34,8 @@ class ParseTreeEncoder:
         value = node.getValue()
         if not isinstance(value, basestring):
             value = ' '.join(value)
-        res = value.replace("'", "").replace('"', '')
-        res = res.replace('*', '').replace('?', '')
+        res = remove_special_chars(value)
+        res = res.replace('\\', '\\\\').replace("'", "''")
         return res
 
     def encode_ATOM(self, node):
